@@ -9,11 +9,11 @@ Data::Hive - convenient access to hierarchical data
 
 =head1 VERSION
 
-Version 0.040
+Version 0.050
 
 =cut
 
-our $VERSION = '0.040';
+our $VERSION = '0.050';
 
 =head1 SYNOPSIS
 
@@ -40,6 +40,8 @@ name and pass it the hive's path:
 
 =item * NAME
 
+=item * DELETE
+
 =back
 
 =head2 NEW
@@ -92,13 +94,15 @@ Retrieve the value represented by this object's path from the store.
 
 =head2 GETNUM
 
-Soley for Perl 5.6.1 compatability, where returning undef
-from overloaded numification causes a segfault.
+=head2 GETSTR
+
+Soley for Perl 5.6.1 compatability, where returning undef from overloaded
+numification/stringification can cause a segfault.
 
 =cut
 
 use overload (
-  q{""}    => 'GET',
+  q{""}    => 'GETSTR',
   q{0+}    => 'GETNUM',
   fallback => 1,
 );
@@ -110,6 +114,11 @@ sub GET {
 
 sub GETNUM { shift->GET || 0 }
 
+sub GETSTR {
+  my $rv = shift->GET;
+  return defined($rv) ? $rv : '';
+}
+
 =head2 SET
 
   $hive->some->path->SET($val);
@@ -179,6 +188,22 @@ sub EXISTS {
   return $self->{store}->exists($self->{path});
 }
 
+=head2 DELETE
+
+  $hive->foo->bar->DELETE;
+
+Delete the value represented by this hive from the store.  Returns the previous
+value, if any.
+
+Throw an exception if the given store can't delete items for some reason.
+
+=cut
+
+sub DELETE {
+  my $self = shift;
+  return $self->{store}->delete($self->{path});
+}
+
 =head1 AUTHOR
 
 Hans Dieter Pearcey, C<< <hdp at cpan.org> >>
